@@ -9,7 +9,9 @@
 #include <KConfigGroup>
 #include <KCrash>
 #include <KDBusService>
+#include <KIconTheme>
 #include <KLocalizedContext>
+#include <KLocalizedQmlContext>
 #include <KLocalizedString>
 #include <KWindowConfig>
 #include <KWindowSystem>
@@ -23,18 +25,8 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QQuickWindow>
-#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
-#include <KLocalizedQmlContext>
-#endif
-#define HAVE_KICONTHEME __has_include(<KIconTheme>)
-#if HAVE_KICONTHEME
-#include <KIconTheme>
-#endif
 
-#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
-#if HAVE_STYLE_MANAGER
 #include <KStyleManager>
-#endif
 static void raiseWindow(QWindow *window)
 {
     KWindowSystem::updateStartupId(window);
@@ -43,9 +35,7 @@ static void raiseWindow(QWindow *window)
 
 int main(int argc, char *argv[])
 {
-#if HAVE_KICONTHEME
     KIconTheme::initTheme();
-#endif
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("merkuro"));
@@ -58,13 +48,7 @@ int main(int argc, char *argv[])
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-#if HAVE_STYLE_MANAGER
     KStyleManager::initStyle();
-#else // !HAVE_STYLE_MANAGER
-#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
-    QApplication::setStyle(QStringLiteral("breeze"));
-#endif
-#endif
 
     KAboutData aboutData(
         // The program name used internally.
@@ -102,12 +86,9 @@ int main(int argc, char *argv[])
     aboutData.processCommandLine(&parser);
 
     const auto mouseTracker = MouseTracker::instance();
-    qmlRegisterSingletonInstance("org.kde.merkuro.calendar.private", 1, 0, "MouseTracker", mouseTracker);
 
     KDBusService service(KDBusService::Unique);
 
-    qmlRegisterType<Importer>("org.kde.merkuro.calendar.private", 1, 0, "Importer");
-
     QQmlApplicationEngine engine;
 
     QObject::connect(&service, &KDBusService::activateRequested, &engine, [&engine, &parser](const QStringList &arguments, const QString &workingDirectory) {
@@ -131,12 +112,8 @@ int main(int argc, char *argv[])
         }
     });
 
-#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-#else
     engine.rootContext()->setContextObject(new KLocalizedQmlContext(&engine));
-#endif
-    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
+    engine.loadFromModule("org.kde.merkuro.calendar", "Main");
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
