@@ -139,21 +139,6 @@ Akonadi::Item ContactManager::getItem(qint64 itemId)
     return item;
 }
 
-QUrl ContactManager::decorationToUrl(QVariant decoration)
-{
-    if (!decoration.canConvert<QImage>()) {
-        return {};
-    }
-
-    auto imgDecoration = decoration.value<QImage>();
-    QByteArray byteArray;
-    QBuffer buffer(&byteArray);
-    buffer.open(QIODevice::WriteOnly);
-    imgDecoration.save(&buffer, "png");
-    const QString base64 = QString::fromUtf8(byteArray.toBase64());
-    return QUrl(QLatin1StringView("data:image/png;base64,") + base64);
-}
-
 void ContactManager::deleteItem(const Akonadi::Item &item)
 {
     new Akonadi::ItemDeleteJob(item);
@@ -182,7 +167,7 @@ void ContactManager::deleteCollection(const Akonadi::Collection &collection)
         auto job = new Akonadi::CollectionDeleteJob(collection, this);
         connect(job, &Akonadi::CollectionDeleteJob::result, this, [](KJob *job) {
             if (job->error()) {
-                qCWarning(MERKURO_LOG) << "Error occurred deleting collection: " << job->errorString();
+                qCWarning(MERKURO_CONTACT_LOG) << "Error occurred deleting collection: " << job->errorString();
             }
         });
         return;
@@ -229,7 +214,7 @@ void ContactManager::setCollectionColor(Akonadi::Collection collection, const QC
     auto modifyJob = new Akonadi::CollectionModifyJob(collection);
     connect(modifyJob, &Akonadi::CollectionModifyJob::result, this, [this, collection, color](KJob *job) {
         if (job->error()) {
-            qCWarning(MERKURO_LOG) << "Error occurred modifying collection color: " << job->errorString();
+            qCWarning(MERKURO_CONTACT_LOG) << "Error occurred modifying collection color: " << job->errorString();
         } else {
             m_colorProxy->setColor(collection.id(), color);
         }
