@@ -9,10 +9,12 @@
 #include <Akonadi/AgentManager>
 #include <Akonadi/AgentTypeModel>
 
+#include <Akonadi/SpecialMailCollections>
 #include <KWindowSystem>
 #include <QPointer>
 
 using namespace Akonadi;
+using namespace Qt::Literals::StringLiterals;
 
 AgentConfiguration::AgentConfiguration(QObject *parent)
     : QObject(parent)
@@ -170,4 +172,10 @@ void AgentConfiguration::setMimetypes(const QStringList &mimetypes)
     }
 }
 
+bool AgentConfiguration::isRemovable(int index)
+{
+    const auto instance = m_runningAgents->data(m_runningAgents->index(index, 0), AgentInstanceModel::InstanceRole).value<AgentInstance>();
+    return !Akonadi::SpecialMailCollections::self()->isSpecialAgent(instance.identifier());
+}
+
 #include "moc_agentconfiguration.cpp"
